#!/bin/sh

umask 027
[ -z "$2" ] && {
	echo "Client name is required!"
	exit 1
}

SCHEMA=DNS
CERTNAME=$2
[ -n "$3" ] && SCHEMA=$3

RUNPATH=$(dirname $0)

. $RUNPATH/cert_vars.sh

[ -n "$PASSWORD" ] && DPASSWORD=$PASSWORD

[ -f $CAKEYDIR/ca.key -a -f $CADIR/ca.crt ] || {
	$RUNPATH/mkcacert.sh $1
	[ $? -eq 0 ] || exit 1
	mkdir -p $TMPPATH
}

cat $RUNPATH/client.cnf | sed -e "s,@DIR@,$CERTDIR,g" -e "s,@DAYS@,$DDAYS,g" -e "s,@PASSWORD@,$DPASSWORD,g" \
    -e "s,@COUNTRY@,$DCOUNTRY,g" -e "s,@ORG@,$DORG,g" -e "s,@EMAIL@,$DEMAIL,g" -e "s,@CN@,$2,g" \
    -e "s,@STATE@,$DSTATE,g" -e "s,@LOCALITY@,$DLOCALITY,g" -e "s,@SCHEMA@,$SCHEMA,g" > $TMPPATH/client.cnf
cat $RUNPATH/extensions | sed -e "s,@CN@,$2,g" -e "s,@SCHEMA@,$SCHEMA,g" > $TMPPATH/extensions

mkdir -p $CERTDIR
mkdir -p $CLIENTCERTDIR

[ -f $CERTDIR/index.txt ] || touch $CERTDIR/index.txt
[ -f "$CERTDIR/serial" ] || echo '01' > $CERTDIR/serial

openssl req -new -out $TMPPATH/$2.csr -keyout $CLIENTCERTDIR/$2.key -config $TMPPATH/client.cnf
EXT=
EXT12=
if [ -n "$PASSWORD" ]; then
	EXT=" -key `grep output_password $RUNPATH/ca.cnf | sed 's/.*=//;s/^ *//'`"
	EXT12=" -passin pass:`grep output_password $TMPPATH/client.cnf | sed 's/.*=//;s/^ *//'` -passout pass:`grep output_password $TMPPATH/client.cnf | sed 's/.*=//;s/^ *//'`"
else
	mv -f $CLIENTCERTDIR/$2.key $TMPPATH/$2.key
	openssl rsa -in $TMPPATH/$2.key -passin pass:$DPASSWORD -out $CLIENTCERTDIR/$2.key
	EXT12=" -passin pass: -passout pass:"
fi

openssl ca -batch -keyfile $CAKEYDIR/ca.key -cert $CADIR/ca.crt $EXT -in $TMPPATH/$2.csr -out $CLIENTCERTDIR/$2.crt \
  -config $TMPPATH/client.cnf -subj "/C=$DCOUNTRY/ST=$DSTATE/L=$DLOCALITY/O=$DORG/CN=$2" -extensions xpclient_ext  -extfile $TMPPATH/extensions
openssl pkcs12 -export -certfile $CADIR/ca.crt -in $CLIENTCERTDIR/$2.crt -inkey $CLIENTCERTDIR/$2.key -out $CLIENTCERTDIR/$2.p12 $EXT12 || exit 1

if [ "x$1" = "xipsec" ]; then
	openssl x509 -outform der -in $CLIENTCERTDIR/$2.crt -out $CLIENTCERTDIR/$2.der
fi

rm -rf $TMPPATH
