#!/bin/sh

[ -z "$2" ] && {
	echo "Server name is required!"
	exit 1
}

SCHEMA=DNS
CERTNAME=cert
[ -n "$3" ] && {
	CERTNAME=$3
	[ -n "$4" ] && SCHEMA=$4
}

RUNPATH=$(dirname $0)

. $RUNPATH/cert_vars.sh

[ -n "$PASSWORD" ] && DPASSWORD=$PASSWORD

[ -f $CAKEYDIR/ca.key -a -f $CADIR/ca.crt ] || {
	$RUNPATH/mkcacert.sh $1
	[ $? -eq 0 ] || exit 1
	mkdir -p $TMPPATH
}

cat $RUNPATH/server.cnf | sed -e "s,@DIR@,$CERTDIR,g" -e "s,@DAYS@,$DDAYS,g" -e "s,@PASSWORD@,$DPASSWORD,g" \
    -e "s,@COUNTRY@,$DCOUNTRY,g" -e "s,@ORG@,$DORG,g" -e "s,@EMAIL@,$DEMAIL,g" -e "s,@CN@,$2,g" \
    -e "s,@STATE@,$DSTATE,g" -e "s,@LOCALITY@,$DLOCALITY,g" -e "s,@SCHEMA@,$SCHEMA,g" > $TMPPATH/server.cnf
cat $RUNPATH/extensions | sed -e "s,@CN@,$2,g" -e "s,@SCHEMA@,$SCHEMA,g" > $TMPPATH/extensions

mkdir -p $CERTDIR
mkdir -p $SERVERCERTDIR

[ -f $CERTDIR/index.txt ] || touch $CERTDIR/index.txt
[ -f $CERTDIR/serial ] || /usr/bin/nu-rand > $CERTDIR/serial
openssl req -new -out $TMPPATH/$2.csr -keyout $SERVERCERTDIR/$CERTNAME.key -config $TMPPATH/server.cnf
EXT=
EXT12=
if [ -n "$PASSWORD" ]; then
	EXT=" -key `grep output_password $RUNPATH/ca.cnf | sed 's/.*=//;s/^ *//'`"
	EXT12=" -passin pass:`grep output_password $TMPPATH/server.cnf | sed 's/.*=//;s/^ *//'` -passout pass:`grep output_password $TMPPATH/server.cnf | sed 's/.*=//;s/^ *//'`"
else
	mv -f $SERVERCERTDIR/$CERTNAME.key $TMPPATH/$2.key
	openssl rsa -in $TMPPATH/$2.key -passin pass:$DPASSWORD -passout pass: -out $SERVERCERTDIR/$CERTNAME.key
	EXT12=" -passin pass: -passout pass:"
fi

openssl ca -batch -keyfile $CAKEYDIR/ca.key -cert $CADIR/ca.crt $EXT -in $TMPPATH/$2.csr -out $SERVERCERTDIR/$CERTNAME.crt \
  -config $TMPPATH/server.cnf -subj "/C=$DCOUNTRY/ST=$DSTATE/L=$DLOCALITY/O=$DORG/CN=$2" -extensions xpserver_ext  -extfile $TMPPATH/extensions
openssl pkcs12 -export -certfile $CADIR/ca.crt -in $SERVERCERTDIR/$CERTNAME.crt -inkey $SERVERCERTDIR/$CERTNAME.key -out $SERVERCERTDIR/$CERTNAME.p12 $EXT12 || exit 1

case "$1" in
web|\
radius)
	cp -f $SERVERCERTDIR/$CERTNAME.key $SERVERCERTDIR/$CERTNAME.pem
	cat $SERVERCERTDIR/$CERTNAME.crt >> $SERVERCERTDIR/$CERTNAME.pem
	;;
ipsec)
	openssl x509 -outform der -in $SERVERCERTDIR/$CERTNAME.crt -out $SERVERCERTDIR/$2.der
	mv -f $SERVERCERTDIR/$CERTNAME.key $CAKEYDIR/$2.key
	;;
esac

rm -rf $TMPPATH
