#!/bin/sh

[ -z "$3" ] && exit 1

TIMESCALEDB=0
[ -f /usr/lib/postgresql/timescaledb.so ] && {
    TIMESCALEDB=1
    grep -v shared_preload_libraries /mnt/data/postgres/data/postgresql.conf > /tmp/.pg.conf
    echo "shared_preload_libraries='timescaledb'" >> /tmp/.pg.conf
    mv -f /tmp/.pg.conf /mnt/data/postgres/data/postgresql.conf
    /etc/init.d/postgresql restart
    sleep 3
}

export PGPASSWORD=postgres
USER=postgres
echo -n "Create database $3 "
echo "CREATE ROLE $1 WITH LOGIN PASSWORD '$2';
CREATE DATABASE $3 WITH OWNER $1 ENCODING 'SQL_ASCII' TEMPLATE 'template0';" > /tmp/pgcmd.sql
psql -U $USER -f /tmp/pgcmd.sql
if [ "$?" = "0" ]; then
	echo "ok"
else
	echo "error"
	exit 1
fi
[ $TIMESCALEDB -eq 1 ] && {
    echo -n "Create TimescaleDB extension for database $3 "
    echo "CREATE EXTENSION timescaledb;" > /tmp/pgcmd.sql
    psql -U $USER -f /tmp/pgcmd.sql $3
    if [ "$?" = "0" ]; then
	echo "ok"
    else
	echo "error"
	exit 1
    fi
}
rm -f /tmp/pgcmd.sql

export PGPASSWORD=$2

echo -n "Create language for database $3 "
echo "CREATE LANGUAGE plpgsql;" > /tmp/pgcmd.sql
psql -U $1 -f /tmp/pgcmd.sql $3
    if [ "$?" = "0" ]; then
	echo "ok"
    else
	echo "error"
	exit 1
    fi
rm -f /tmp/pgcmd.sql

echo "Insert data into database"

for f in /opt/stasoft/contrib/data/pgsql/*.pgsql; do
    echo -n "Process $f "
    F=$(basename $f)
    cat $f | sed -e "s/@dbuser@/$1/g" > /tmp/$F
    psql -U $1 -f /tmp/$F -q $3
    if [ "$?" = "0" ]; then
	echo "ok"
    else
	echo "error"
	break
    fi
    rm /tmp/$F
done

FNAME=/opt/stasoft/bin/apply_profile.php
[ -x $FNAME ] && {
    echo "{\"cfg\":{\"DB\":{\"DEBUG\":0,\"TRANSACTION\":1,\"URI\":\"pgsql:\/\/$1:$2@localhost\/$3\"}}}" > /tmp/.main.pgsql.conf
    $FNAME /tmp/.main.pgsql.conf
    rm -f /tmp/.main.pgsql.conf
}

[ ! -d /etc/php7 -a -f /etc/php.ini ] && {
    grep -v pdo /etc/php.ini > /tmp/.php.ini
    echo "extension=pdo.so
extension=pdo_pgsql.so" >> /tmp/.php.ini
    mv -f /tmp/.php.ini /etc/php.ini
}
