#!/bin/sh

. /opt/stasoft/lib/netlib.sh

SERVICE=httpd

config_n_run() {
    local ADDRESS=$1
    local PORT=$2
    local FCFG="/var/run/.etc/httpd.$ADDRESS.$PORT.conf"
    echo "user=root
nochroot
cgipat=**.cgi|**.php
charset=utf-8
pidfile=/var/run/httpd.$ADDRESS.$PORT.pid
data_dir=/opt/stasoft/www
port=$PORT
host=$ADDRESS
" > $FCFG
    [ -d /proc/sys/net/ipv6 ] && [ "$ADDRESS"="0.0.0.0" ] && echo "host=::" >> $FCFG
    [ $PORT -eq 443 ] && {
	/opt/stasoft/bin/chttp_cert.sh
	echo "cipher=AES128-SHA
ssl" >> $FCFG
if [ -f /etc/cert/websrv.pem ]; then
    echo "certfile=/etc/cert/websrv.pem" >> $FCFG
else
    echo "certfile=/etc/cert/authority/web/server/cert.pem" >> $FCFG
fi
    }
    /sbin/start-stop-daemon -p /var/run/httpd.$ADDR.$PORT.pid -b -S -x /usr/sbin/httpd -- -C $FCFG
}

start() {
    local APORT=$1
    local PORT=$(cfg_get_val services:http:enable)

    [ "x$PORT" = "x1" ] || return 0

    local ADDRESS='0.0.0.0'

    if [ -n "$APORT" ]; then
	PORT=80
    else
	PORT=$(cfg_get_val services:http:bind:port)
	[ -z "$PORT" ] && PORT=443
    fi
    local PID1=$(get_pid httpd -C)
    if [ -n "$PID1" ]; then
	local PIDFILE=/var/run/httpd.$ADDRESS.$PORT.pid
	if [ -f $PIDFILE ]; then
	    local PID2=$(cat $PIDFILE)
	    [ "x$PID1" = "x$PID2" ] && return 0
	    rm -f $PIDFILE
	else
	    return 0
	fi
    else
	rm -f /var/run/httpd.*.*.pid
    fi
    ln -sf /opt/stasoft/www/index.html /tmp/index.html
    ln -sf /opt/stasoft/www/index.html /var/run/index.html
    ln -sf /opt/stasoft/www/index.html /var/run/.etc/index.html
    ln -sf /opt/stasoft/www/index.html /var/log/index.html
    ln -sf /opt/stasoft/www/index.html /var/lock/index.html
    ln -sf /opt/stasoft/www/index.html /var/spool/index.html
    TZ=''
    [ -f /etc/TZ ] && TZ=$(cat /etc/TZ)
    [ -n "$TZ" ] && export TZ
    PATH="/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin:$PATH"
    export PATH
    config_n_run $ADDRESS $PORT
    [ $PORT -eq 443 ] || {
	[ -f /opt/stasoft/etc/.ac ] && config_n_run $ADDRESS 443

    }
}

service_lock $SERVICE

case "$1" in
    start)
	start $2
    ;;
    stop)
	service_stop $SERVICE
    ;;
    restart)
	service_stop $SERVICE
	sleep 1
	start $2
    ;;
    *)
	echo "Usage: $0 {start|stop|restart}"
    ;;
esac

service_unlock $SERVICE
